@@ -3,6 +3,7 @@ from pathlib import Path
 from itertools import chain
 from types import MethodType
 
+from django import VERSION as DJANGO_VERSION
 from django.conf import settings
 from django.contrib import admin, messages
 from django.contrib.contenttypes.forms import BaseGenericInlineFormSet
@@ -498,6 +499,14 @@ class SortableInlineAdminMixin:
         return fields
 
 
+class SortableStackedInline(SortableInlineAdminMixin, admin.StackedInline):
+    template = 'adminsortable2/edit_inline/stacked-django-{0}.{1}.html'.format(*DJANGO_VERSION)
+
+
+class SortableTabularInline(SortableInlineAdminMixin, admin.TabularInline):
+    template = 'adminsortable2/edit_inline/tabular-django-{0}.{1}.html'.format(*DJANGO_VERSION)
+
+
 class CustomGenericInlineFormSet(CustomInlineFormSetMixin, BaseGenericInlineFormSet):
     def get_max_order(self):
         query_set = self.model.objects.filter(
